<?php

namespace Drupal\radioactivity;

use Drupal\field\FieldStorageConfigInterface;

/**
 * Interface RadioactivityProcessorInterface.
 *
 * @package Drupal\radioactivity
 */
interface RadioactivityProcessorInterface {

  /**
   * Apply decay to entities.
   *
   * @return int
   *   The number of decays processed.
   */
  public function processDecay();

  /**
   * Queue processing of Radioactivity decays.
   *
   * @param \Drupal\field\FieldStorageConfigInterface $fieldConfig
   *   Configuration of the field to be processed.
   * @param array $entityIds
   *   Entity IDs to be processed.
   */
  public function queueProcessDecay(FieldStorageConfigInterface $fieldConfig, array $entityIds);

  /**
   * Process emits from the queue.
   *
   * @return int
   *   The number of emits processed.
   */
  public function processIncidents();

  /**
   * Queue processing of Radioactivity emission incidents.
   *
   * @param string $entityType
   *   Incident entity type.
   * @param \Drupal\radioactivity\Incident[][] $entityIncidents
   *   Radioactivity incidents grouped per entity ID (1st) and incident ID
   *   (2nd).
   */
  public function queueProcessIncidents($entityType, array $entityIncidents);

}
